<?php

	# 		Air Quality Index World
	# 		Namespace:		airQualityWorld
	#		Meteotemplate Block
	
	#		v2.0 - Nov 11, 2016
	#			- added logging
	#			- optimization
	#		v2.1 - Mar 25, 2017
	#			- language improvements
	#		v3.0 - Aug 26, 2017
	#			- CSS tweaks
	
	$thisBlockVersion = "3.0";
	
	$time = microtime();
	$time = explode(' ', $time);
	$time = $time[1] + $time[0];
	$blockStartTime = $time;
	
	$errorLog[] = array("","%c Loading Air Quality World Block ".$thisBlockVersion."','font-weight:bold;color:green");
	
	if(file_exists("settings.php")){
		include("settings.php");
	}
	else{
		echo "Please go to your admin section and go through the settings for this block first.";
		die();
	}	
	
	$errorLog[] = array("","URL for data retrieval: ".$url);
	$errorLog[] = array("","Cache time: 3 hours");
	
	// load theme
	$designTheme = json_decode(file_get_contents("../../css/theme.txt"),true);
	$theme = $designTheme['theme'];
	
	include("../../../config.php");
	include("../../../css/design.php");
	include("../../../scripts/functions.php");
	
	$languageRaw = file_get_contents($baseURL."lang/gb.php");
	$language['gb'] = json_decode($languageRaw,true);
	$languageRaw = file_get_contents($baseURL."lang/".$lang.".php");
	$language[$lang] = json_decode($languageRaw,true);
	
	if(file_exists("cache/airQualityCache.txt")){
		if (time()-filemtime("cache/airQualityCache.txt") > 60 * 180) {
			unlink("cache/airQualityCache.txt");
			$errorLog[] = array("","Cache outdated, deleting cache file.");
			if(file_exists("cache/airQualityCache.txt")){
				$errorLog[] = array("w","Cache file was not deleted, likely permission problem. Cache file cannot be refreshed and data is outdated.");
			}
		}
	}

	if(file_exists("cache/airQualityCache.txt")){
		$fileData = file_get_contents("cache/airQualityCache.txt");
		$errorLog[] = array("","Loading data from cache file.");
	}
	else { 
		$fileData = curlMain($url,8);
		if($fileData==""){
			$errorLog[] = array("w","No data returned from the URL specified.");
			$errorLog[] = array("","Trying alternative method for retrieving data...");
			$fileData = file_get_contents($url);
			if($fileData==""){
				$errorLog[] = array("e","No data loaded even using alternative method.");
			}
			else{
				$errorLog[] = array("","Data loaded using alternative method.");
			}
		}
		if($fileData!=""){
			$errorLog[] = array("","Saving cache file for Air Quality World");
			$cached = fopen("cache/airQualityCache.txt", "w");
			fwrite($cached, $fileData);
			fclose($cached);
			if(!file_exists("cache/airQualityCache.txt")){
				$errorLog[] = array("w","Cache file was not created - likely permission issue. Cache directory not writable.");
			}
		}
	}
	
	$conditions = array(lang('good','c'),lang('moderate','c'),lang('unhealthy for sensitive groups','c'),lang('unhealthy','c'),lang('very unhealthy','c'),lang('hazardous','c'));
	$bgColors = array('#00B300','#FFFF00','#FF8000','#FF2626','#B30086','#000000');
	$fontColors = array('#FFFFFF','#000000','#FFFFFF','#FFFFFF','#FFFFFF','#FFFFFF');
	
	$values = array();
	
	preg_match("/<title>(.*?)<\/title>/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$cityRaw = $matches[1];
	}
	
	preg_match("/\"time\"\:\"Updated on(.*?)\"\}/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$values['update'] = trim($matches[1]);
	}
	
	$cityExploded = explode(":",$cityRaw);
	$city = $cityExploded[0];
	$city = str_replace("Air Pollution","",$city);
	$city = trim($city);
	
	preg_match("/p\"\:\"pm25\",\"v\"\:\[([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?)]/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$values['pm25'] = array($matches[1],$matches[2],$matches[3]);
	}
	
	preg_match("/p\"\:\"pm10\",\"v\"\:\[([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?)]/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$values['pm10'] = array($matches[1],$matches[2],$matches[3]);
	}
	
	preg_match("/p\"\:\"o3\",\"v\"\:\[([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?)]/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$values['o3'] = array($matches[1],$matches[2],$matches[3]);
	}
	
	preg_match("/p\"\:\"no2\",\"v\"\:\[([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?)]/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$values['no2'] = array($matches[1],$matches[2],$matches[3]);
	}
	
	preg_match("/p\"\:\"so2\",\"v\"\:\[([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?),([0-9][0-9]?[0-9]?)]/",$fileData,$matches);
	if(array_key_exists(1,$matches)){
		$values['so2'] = array($matches[1],$matches[2],$matches[3]);
	}
	
	$details = "<table class='table aqiWorldTable'>";
	
	if(array_key_exists('pm25',$values)){
		$position = getCondition($values['pm25'][0]);
		$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>PM2.5</td><td style='text-align:justify'>";
		if($position==0){
			$details = $details."It’s a great day to be active outside.";
		}
		if($position==1){
			$details = $details."<strong>Unusually sensitive people</strong><br>Consider reducing prolonged or heavy exertion. Watch for symptoms such as coughing or shortness of breath. These are signs to take it easier.<br><br><strong>Everyone else</strong><br>It’s a good day to be active outside.";
		}
		if($position==2){
			$details = $details."<strong>Sensitive groups</strong><br>Reduce prolonged or heavy exertion. It’s OK to be active outside, but take more breaks and do less intense activities. Watch for symptoms such as coughing or shortness of breath.<br><br><strong>People with asthma</strong><br>People with asthma should follow their asthma action plans and keep quick relief medicine handy.<br><br><strong>People with heart disease<br>Symptoms such as palpitations, shortness of breath, or unusual fatigue may indicate a serious problem. If you have any of these, contact your heath care provider.";
		}
		if($position==3){
			$details = $details."<strong>Sensitive groups</strong><br>Avoid prolonged or heavy exertion. Move activities indoors or reschedule to a time when the air quality is better.<br><br><strong>Everyone else</strong><br>Reduce prolonged or heavy exertion. Take more breaks during all outdoor activities.";
		}
		if($position==4){
			$details = $details."<strong>Sensitive groups</strong><br>Avoid all physical activity outdoors. Move activities indoors or reschedule to a time when air quality is better.<br><br><strong>Everyone else</strong><br>Avoid prolonged or heavy exertion. Consider moving activities indoors or rescheduling to a time when air quality is better.";
		}
		if($position==5){
			$details = $details."<strong>Everyone</strong><br>Avoid all physical activity outdoors.<br><br><strong>Sensitive groups</strong><br>Remain indoors and keep activity levels low. Follow tips for keeping particle levels low indoors.";
		}
		$details = $details."</td></tr>";
	}
	
	if(array_key_exists('pm10',$values)){
		$position = getCondition($values['pm10'][0]);
		$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>PM10</td><td style='text-align:justify'>";
		if($position==0){
			$details = $details."It’s a great day to be active outside.";
		}
		if($position==1){
			$details = $details."<strong>Unusually sensitive people</strong><br>Consider reducing prolonged or heavy exertion. Watch for symptoms such as coughing or shortness of breath. These are signs to take it easier.<br><br><strong>Everyone else</strong><br>It’s a good day to be active outside.";
		}
		if($position==2){
			$details = $details."<strong>Sensitive groups</strong><br>Reduce prolonged or heavy exertion. It’s OK to be active outside, but take more breaks and do less intense activities. Watch for symptoms such as coughing or shortness of breath.<br><br><strong>People with asthma</strong><br>People with asthma should follow their asthma action plans and keep quick relief medicine handy.<br><br><strong>People with heart disease<br>Symptoms such as palpitations, shortness of breath, or unusual fatigue may indicate a serious problem. If you have any of these, contact your heath care provider.";
		}
		if($position==3){
			$details = $details."<strong>Sensitive groups</strong><br>Avoid prolonged or heavy exertion. Move activities indoors or reschedule to a time when the air quality is better.<br><br><strong>Everyone else</strong><br>Reduce prolonged or heavy exertion. Take more breaks during all outdoor activities.";
		}
		if($position==4){
			$details = $details."<strong>Sensitive groups</strong><br>Avoid all physical activity outdoors. Move activities indoors or reschedule to a time when air quality is better.<br><br><strong>Everyone else</strong><br>Avoid prolonged or heavy exertion. Consider moving activities indoors or rescheduling to a time when air quality is better.";
		}
		if($position==5){
			$details = $details."<strong>Everyone</strong><br>Avoid all physical activity outdoors.<br><br><strong>Sensitive groups</strong><br>Remain indoors and keep activity levels low. Follow tips for keeping particle levels low indoors.";
		}
		$details = $details."</td></tr>";
	}
	
	if(array_key_exists('o3',$values)){
		$position = getCondition($values['o3'][0]);
		$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>Ozone</td><td style='text-align:justify'>";
		if($position==0){
			$details = $details."It’s a great day to be active outside.";
		}
		if($position==1){
			$details = $details."<strong>Unusually sensitive people</strong><br>Consider reducing prolonged or heavy outdoor exertion. Watch for symptoms such as coughing or shortness of breath. These are signs to take it a little easier.<br><br><strong>Everyone else</strong><br>It’s a good day to be active outside.";
		}
		if($position==2){
			$details = $details."<strong>Sensitive groups</strong><br>Reduce prolonged or heavy outdoor exertion. Take more breaks, do less intense activities. Watch for symptoms such as coughing or shortness of breath. Schedule outdoor activities in the morning when ozone is lower.<br><br><strong>People with asthma</strong><br>People with asthma should follow their asthma action plans and keep quick relief medicine handy.";
		}
		if($position==3){
			$details = $details."<strong>Sensitive groups</strong><br>Avoid prolonged or heavy outdoor exertion. Schedule outdoor activities in the morning when ozone is lower. Consider moving activities indoors.<br><br><strong>People with asthma</strong><br>People with asthma should keep quick-relief medicine handy.<br><br><strong>Everyone else</strong><br>Reduce prolonged or heavy outdoor exertion. Take more breaks, do less intense activities. Schedule outdoor activities in the morning when ozone is lower.";
		}
		if($position==4){
			$details = $details."<strong>Sensitive groups</strong><br>Avoid all physical activity outdoors. Move activities indoors or reschedule to a time when air quality is better.<br><br><strong>People with asthma</strong><br>People with asthma should keep quick-relief medicine handy.<br><br><strong>Everyone else</strong><br>Avoid prolonged or heavy outdoor exertion. Schedule outdoor activities in the morning when ozone is lower. Consider moving activities indoors.";
		}
		if($position==5){
			$details = $details."<strong>Everyone</strong><br>Avoid all physical activity outdoors.";
		}
		$details = $details."</td></tr>";
	}
	
	if(array_key_exists('no2',$values)){
		$position = getCondition($values['no2'][0]);
		$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>NO<sub>2</sub></td><td style='text-align:justify'>";
		if($position==0){
			$details = $details."It’s a great day to be active outside.";
		}
		if($position==1){
			$details = $details."Few hypersensitive individuals should reduce outdoor exercise.";
		}
		if($position==2){
			$details = $details."Slight irritations may occur, individuals with breathing or heart problems should reduce outdoor exercise.";
		}
		if($position==3){
			$details = $details."May cause breathing discomfort to people with lung disease such as asthma, and discomfort to people with heart disease, children and older adults.";
		}
		if($position==4){
			$details = $details."Healthy people will be noticeably affected. People with breathing or heart problems will experience reduced endurance in activities. These individuals and elders should remain indoors and restrict activities.";
		}
		if($position==5){
			$details = $details."Healthy people will experience reduced endurance in activities. There may be strong irritations and symptoms and may trigger other illnesses. Elders and the sick should remain indoors and avoid exercise. Healthy individuals should avoid out door activities.";
		}
		$details = $details."</td></tr>";
	}
	
	if(array_key_exists('so2',$values)){
		$position = getCondition($values['so2'][0]);
		$details = $details."<tr><td style='padding-right:2px;font-weight:bold'>SO<sub>2</sub></td><td style='text-align:justify'>";
		if($position==0){
			$details = $details."It’s a great day to be active outside.";
		}
		if($position==1){
			$details = $details."Few hypersensitive individuals should reduce outdoor exercise.";
		}
		if($position==2){
			$details = $details."Slight irritations may occur, individuals with breathing or heart problems should reduce outdoor exercise.";
		}
		if($position==3){
			$details = $details."May cause breathing discomfort to people with lung disease such as asthma, and discomfort to people with heart disease, children and older adults.";
		}
		if($position==4){
			$details = $details."Healthy people will be noticeably affected. People with breathing or heart problems will experience reduced endurance in activities. These individuals and elders should remain indoors and restrict activities.";
		}
		if($position==5){
			$details = $details."Healthy people will experience reduced endurance in activities. There may be strong irritations and symptoms and may trigger other illnesses. Elders and the sick should remain indoors and avoid exercise. Healthy individuals should avoid out door activities.";
		}
		$details = $details."</td></tr>";
	}
	
	$details = $details."</table>";
	
	function getCondition($index){
		if($index<=50){
			$position = 0;
		}
		else if($index>=51 && $index<=100){
			$position = 1;
		}
		else if($index>=101 && $index<=150){
			$position = 2;
		}
		else if($index>=151 && $index<=200){
			$position = 3;
		}
		else if($index>=201 && $index<=300){
			$position = 4;
		}
		else{
			$position = 5;
		}
		return $position;
	}
	
?>
	<style>
		.aqiWorldicon{
			max-width:45px;
			width:100%;
		}
		.aqiWorldTable td{
			padding: 2%;
		}
		#aqiWorldDetails table td{
			padding: 8px;
		}
		.airQualitySingle{
			display: inline-block;
			font-size: 20px;
			width: 27px;
			padding: 2px;
			font-weight:bold;
			border:3px solid <?php echo $theme=="dark" ? 'white' : 'black'?>;
			border-radius:5px;
		}
	</style>
	<?php 
		if(count($values)>0){
	?>

		<div style="width:98%;margin:0 auto;text-align:center">
		<?php 
		$airAlertTriggered=false;
		if ($airAlertActive) {			
			$currentAlertValue=-1;
			if(array_key_exists($airAlertField,$values)){			
				$currentAlertValue= $values[$airAlertField][0];
			}			
			if($airAlertValue<0) $airAlertValue=0;			
			if($currentAlertValue>$airAlertValue) $airAlertTriggered=true;			
			if($airAlertTriggered){ 
		?>
				<div class="mticon-warninggeneral" id="AirAlert"> <?php echo $airAlertString?></div>
	
				<?php 

				if($airAlertOnly) { 
				?>
				<div id="airMore"><span class="more" onclick="txt = $('#airGeneral').is(':visible') ? '<?php echo lang('more','l')?>' : '<?php echo lang('hide','l')?>';$('#airGeneral').slideToggle(800);$(this).text(txt)">
						<?php echo lang('more','l')?>
				</span></div>
				<?php
				} 
				?>
		<?php
			}
		}		
		?>
	     <div id="airGeneral">
			<h2><?php echo $city?></h2>
			<?php echo lang("air quality","c")?>
			<br>
			<?php
				if(array_key_exists('pm25',$values) || array_key_exists('pm10',$values) || array_key_exists('o3',$values) || array_key_exists('no2',$values) || array_key_exists('so2',$values)){
			?>	
					<?php
						if(array_key_exists('update',$values)){
							$values['update'] = str_replace("Monday",lang('monday','c'),$values['update']);
							$values['update'] = str_replace("Tuesday",lang('tuesday','c'),$values['update']);
							$values['update'] = str_replace("Wednesday",lang('wednesday','c'),$values['update']);
							$values['update'] = str_replace("Thursday",lang('thursday','c'),$values['update']);
							$values['update'] = str_replace("Friday",lang('friday','c'),$values['update']);
							$values['update'] = str_replace("Saturday",lang('saturday','c'),$values['update']);
							$values['update'] = str_replace("Sunday",lang('sunday','c'),$values['update']);
					?>
							<span style="color:#<?php echo $color_schemes[$design2]['200']?>;font-size:0.9em;font-variant:small-caps;font-weight:bold"><?php echo $values['update']?></span><br>
					<?php
						}
					?>
					<?php
						if(array_key_exists('pm25',$values)){
							$position = getCondition($values['pm25'][0]);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;text-align:center">
								<img src="homepage/blocks/airQualityWorld/icons/<?php echo $theme?>/pm25.png" class="aqiWorldicon"><br>
								<div class="airQualitySingle" style="background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $values['pm25'][0]?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<?php
						if(array_key_exists('pm10',$values)){
							$position = getCondition($values['pm10'][0]);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;text-align:center">
								<img src="homepage/blocks/airQualityWorld/icons/<?php echo $theme?>/pm10.png" class="aqiWorldicon"><br>
								<div class="airQualitySingle" style="background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $values['pm10'][0]?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<?php
						if(array_key_exists('o3',$values)){
							$position = getCondition($values['o3'][0]);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;text-align:center">
								<img src="homepage/blocks/airQualityWorld/icons/<?php echo $theme?>/o3.png" class="aqiWorldicon"><br>
								<div class="airQualitySingle" style="background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $values['o3'][0]?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<?php
						if(array_key_exists('so2',$values)){
							$position = getCondition($values['so2'][0]);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;text-align:center">
								<img src="homepage/blocks/airQualityWorld/icons/<?php echo $theme?>/so2.png" class="aqiWorldicon"><br>
								<div class="airQualitySingle" style="background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $values['so2'][0]?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<?php
						if(array_key_exists('no2',$values)){
							$position = getCondition($values['no2'][0]);
					?>
							<div style="margin:0 auto;padding:10px;display:inline-block;text-align:center">
								<img src="homepage/blocks/airQualityWorld/icons/<?php echo $theme?>/no2.png" class="aqiWorldicon"><br>
								<div class="airQualitySingle" style="background:<?php echo $bgColors[$position]?>;color:<?php echo $fontColors[$position]?>"><?php echo $values['no2'][0]?></div><br><br><span style="font-size:1.3em;font-variant:small-caps;font-weight:bold"><?php echo $conditions[$position]?></span>
							</div>
					<?php
						}
					?>
					<br>
					<div id="aqiWorldDetails" class="details">
						<br>
						<span style="color:#<?php echo $color_schemes[$design2]['200']?>;font-size:1.1em;font-variant:small-caps;font-weight:bold"><?php echo lang("last","c")?> 5 <?php echo lang('days','l')?></span>
						<br>
						<table class="table">
							<tr>
								<td></td>
								<td>
									<?php echo lang('minimumAbbr','c')?>
								</td>
								<td>
									<?php echo lang('maximumAbbr','c')?>
								</td>
							</tr>
						<?php
							if(array_key_exists('pm25',$values)){
						?>
								<tr>
									<td>
										PM2.5
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['pm25'][1])]?>;color:<?php echo $fontColors[getCondition($values['pm25'][1])]?>"><?php echo $values['pm25'][1]?></div>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['pm25'][2])]?>;color:<?php echo $fontColors[getCondition($values['pm25'][2])]?>"><?php echo $values['pm25'][2]?></div>
									</td>
								</tr>
						<?php
							}
						?>
						<?php
							if(array_key_exists('pm10',$values)){
						?>
								<tr>
									<td>
										PM10
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['pm10'][1])]?>;color:<?php echo $fontColors[getCondition($values['pm10'][1])]?>"><?php echo $values['pm10'][1]?></div>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['pm10'][2])]?>;color:<?php echo $fontColors[getCondition($values['pm10'][2])]?>"><?php echo $values['pm10'][2]?></div>
									</td>
								</tr>
						<?php
							}
						?>
						<?php
							if(array_key_exists('o3',$values)){
						?>
								<tr>
									<td>
										O<sub>3</sub>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['o3'][1])]?>;color:<?php echo $fontColors[getCondition($values['o3'][1])]?>"><?php echo $values['o3'][1]?></div>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['o3'][2])]?>;color:<?php echo $fontColors[getCondition($values['o3'][2])]?>"><?php echo $values['o3'][2]?></div>
									</td>
								</tr>
						<?php
							}
						?>
						<?php
							if(array_key_exists('no2',$values)){
						?>
								<tr>
									<td>
										NO<sub>2</sub>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['no2'][1])]?>;color:<?php echo $fontColors[getCondition($values['no2'][1])]?>"><?php echo $values['no2'][1]?></div>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['no2'][2])]?>;color:<?php echo $fontColors[getCondition($values['no2'][2])]?>"><?php echo $values['no2'][2]?></div>
									</td>
								</tr>
						<?php
							}
						?>
						<?php
							if(array_key_exists('so2',$values)){
						?>
								<tr>
									<td>
										SO<sub>2</sub>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['so2'][1])]?>;color:<?php echo $fontColors[getCondition($values['so2'][1])]?>"><?php echo $values['so2'][1]?></div>
									</td>
									<td>
										<div style="display:inline-block;font-weight:bold;font-size:1em;border:1px solid white;border-radius:3px;padding:4px;background:<?php echo $bgColors[getCondition($values['so2'][2])]?>;color:<?php echo $fontColors[getCondition($values['so2'][2])]?>"><?php echo $values['so2'][2]?></div>
									</td>
								</tr>
						<?php
							}
						?>
						</table>
						<h4><?php echo lang("current",'c')?></h4>
						<?php echo $details?>
					</div>
					<span class="more" onclick="txt = $('#aqiWorldDetails').is(':visible') ? '<?php echo lang('more','l')?>' : '<?php echo lang('hide','l')?>';$('#aqiWorldDetails').slideToggle(800);$(this).text(txt)">
						<?php echo lang('more','l')?>
					</span>
					<br>
					<a href="#"><span id="AIQinfoDivOpenerWorld">AQI <?php echo lang('info','l')?></span></a>
			<?php
				}
				else{
			?>
					<br><span style="font-size:1.0em;font-variant:small-caps;font-weight:bold"><?php echo lang('data currently not available','c')?></span>
			<?php
				}
			?>
			<div style="font-size:0.8em;font-variant:small-caps"><?php echo lang('data source','c')?>: aqicn.org</div>
		</div>
	<?php
		}
		else{
			echo lang("data currently not available","c");
		}
	?>
	</div>
	<div id="AIQinfoDivWorld">
		<h1>Air Quality Index</h1>
		<br>
		<table class="table">
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[0]?>;color:<?php echo $fontColors[0]?>">Good</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Air quality is considered satisfactory, and air pollution poses little or no risk.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[1]?>;color:<?php echo $fontColors[1]?>">Moderate</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Air quality is acceptable; however, for some pollutants there may be a moderate health concern for a very small number of people. For example, people who are unusually sensitive to ozone may experience respiratory symptoms.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[2]?>;color:<?php echo $fontColors[2]?>">Unhealthy for Sensitive Groups</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Although general public is not likely to be affected at this AQI range, people with lung disease, older adults and children are at a greater risk from exposure to ozone, whereas persons with heart and lung disease, older adults and children are at greater risk from the presence of particles in the air.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[3]?>;color:<?php echo $fontColors[3]?>">Unhealthy</div>
				</td>
				<td style="text-align:justify;padding:3px">
					Everyone may begin to experience some adverse health effects, and members of the sensitive groups may experience more serious effects.
				</td>
			</tr>
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[4]?>;color:<?php echo $fontColors[4]?>">Very Unhealthy</div>
				</td>
				<td style="text-align:justify;padding:3px">
					This would trigger a health alert signifying that everyone may experience more serious health effects.
				</td>
			</tr>	
			<tr>
				<td>
					<div style="text-align:center;display:inline-block;min-width:45px;font-weight:bold;font-size:1.0em;border:3px solid white;border-radius:5px;padding:2px;margin:10px;background:<?php echo $bgColors[5]?>;color:<?php echo $fontColors[5]?>">Hazardous</div>
				</td>
				<td style="text-align:justify;padding:3px">
					This would trigger a health warnings of emergency conditions. The entire population is more likely to be affected.
				</td>
			</tr>				
		</table>
		<br>
		<h2>PM<sub>2.5</sub></h2>
		<p>
			Fine particles (PM2.5) are 2.5 micrometers in diameter or smaller, and can only be seen with an electron microscope. Fine particles are produced from all types of combustion, including motor vehicles, power plants, residential wood burning, forest fires, agricultural burning, and some industrial processes.
		</p>
		<h2>PM<sub>10</sub></h2>
		<p>
			Coarse dust particles (PM10) are 2.5 to 10 micrometers in diameter. Sources include crushing or grinding operations and dust stirred up by vehicles on roads.
		</p>
		<h2>Ozone (tropospheric)</h2>
		<p>
			Ozone (O3) is a constituent of the troposphere. The troposphere extends from the Earth's surface to between 12 and 20 kilometers above sea level and consists of many layers. At abnormally high concentrations brought about by human activities (largely incomplete combustion of fossil fuels, such as gasoline, diesel, etc.), it is a pollutant, and a constituent of smog. Many highly energetic reactions produce it, ranging from combustion to photocopying. Often laser printers will have a smell of ozone, which in high concentrations is toxic. Ozone is a powerful oxidizing agent readily reacting with other chemical compounds to make many possibly toxic oxides. Health effects depend on ozone precursors, which is a group of pollutants, primarily generated during the combustion of fossil fuels. Reaction with daylight ultraviolet (UV) rays and these precursors create ground-level ozone pollution. (Source:Wikipedia)
		</p>
		<h2>Sulfur dioxide (SO<sub>2</sub>)</h2>
		<p>
			Current scientific evidence links short-term exposures to SO2, ranging from 5 minutes to 24 hours, with an array of adverse respiratory effects including bronchoconstriction and increased asthma symptoms.  These effects are particularly important for asthmatics at elevated ventilation rates (e.g., while exercising or playing.) Studies also show a connection between short-term exposure and increased visits to emergency departments and hospital admissions for respiratory illnesses, particularly in at-risk populations including children, the elderly, and asthmatics. (Source:EPA)
		</p>
		<h2>Nitrogen dioxide (NO<sub>2</sub>)</h2>
		<p>
			Current scientific evidence links short-term NO2 exposures, ranging from 30 minutes to 24 hours, with adverse respiratory effects including airway inflammation in healthy people and increased respiratory symptoms in people with asthma. Also, studies show a connection between breathing elevated short-term NO2 concentrations, and increased visits to emergency departments and hospital admissions for respiratory issues, especially asthma. (Source:EPA)
		</p>
	</div>
	<script>
	<?php if ($airAlertActive) { ?>
				var pathname = window.location.pathname; // Returns path only
				var indexMobile      = 'indexMobile.php';     // Returns full URL
				if(pathname.indexOf(indexMobile) !== -1) {
					<?php if($airAlertOnly) {	
						if ($airAlertTriggered) {?>				
							$('#airGeneral').hide();
						<?php }
						else { 
						?>						
						$("#airQualityWorldBlock").hide();
						<?php
						}
						}
					else
					{?>
					$('#airMore').hide();					
					<?php }?>
				}
				else
				{
				$('#airMore').hide();	
				}
	<?php } ?>
	
		$( "#AIQinfoDivWorld" ).dialog({
			autoOpen: false,
			show: {
				effect: "puff",
				duration: 500
			},
			hide: {
				effect: "puff",
				duration: 500
			},
			height: 800,
			width: '40%',
			position:{
				my: 'top', 
				at: 'top+5%'
			}
		});
		$("#AIQinfoDivOpenerWorld").click(function(){
			$( "#AIQinfoDivWorld" ).dialog( "open" );
		});
	</script>
	
	<?php
		$time = microtime();
		$time = explode(' ', $time);
		$time = $time[1] + $time[0];
		$blockEndTime = $time;
		$blockLoadTime = $blockEndTime - $blockStartTime;
		$blockLoadTime = round($blockLoadTime,4);
		$errorLog[] = array("","Block loaded in ".$blockLoadTime." s.");
		showLog($errorLog);
	?>